@@ -26,8 +26,8 @@ from traitlets import (
 
 from traitlets.utils.importstring import import_item
 
+from .filters.markdown_mistune import InvalidNotebook  # noqa For backward compatibility
 from .exporters.base import get_export_names, get_exporter
-from .exporters.templateexporter import TemplateExporter
 from nbconvert import exporters, preprocessors, writers, postprocessors, __version__
 from .utils.base import NbConvertBase
 from .utils.exceptions import ConversionException
@@ -55,6 +55,7 @@ nbconvert_aliases.update({
     'to' : 'NbConvertApp.export_format',
     'template' : 'TemplateExporter.template_name',
     'template-file' : 'TemplateExporter.template_file',
+    'theme' : 'HTMLExporter.theme',
     'writer' : 'NbConvertApp.writer_class',
     'post': 'NbConvertApp.postprocessor_class',
     'output': 'NbConvertApp.output_base',
@@ -148,7 +149,14 @@ nbconvert_flags.update({
             'exclude_input': False,
             }
         },
-        """Shows code input. This is flag is only useful for dejavu users."""
+        """Shows code input. This flag is only useful for dejavu users."""
+        ),
+    'embed-images' : (
+        {'HTMLExporter' : {
+            'embed_images': True,
+            }
+        },
+        """Embed the images as base64 dataurls in the output. This flag is only useful for the HTML/WebPDF/Slides exports."""
         ),
 })
 
@@ -210,8 +218,8 @@ class NbConvertApp(JupyterApp):
         > jupyter nbconvert --to latex mynotebook.ipynb
 
         Both HTML and LaTeX support multiple output templates. LaTeX includes
-        'base', 'article' and 'report'.  HTML includes 'basic' and 'full'. You
-        can specify the flavor of the format used.
+        'base', 'article' and 'report'.  HTML includes 'basic', 'lab' and 
+        'classic'. You can specify the flavor of the format used.
 
         > jupyter nbconvert --to html --template lab mynotebook.ipynb
         
@@ -595,6 +603,7 @@ class DejavuApp(NbConvertApp):
     def default_export_format(self):
         return 'html'
 
+
 #-----------------------------------------------------------------------------
 # Main entry point
 #-----------------------------------------------------------------------------
